@@ -1,8 +1,8 @@
 extern crate ffmpeg_next as ffmpeg;
 
 use super::{
-    images::{get_size, ImageBuffer},
-    resize::resize_image,
+    images::ImageBuffer,
+    resize::{restrict_size, resize_image},
 };
 use crate::item_sort_list::{FileItem, Orientation};
 use image::imageops;
@@ -113,7 +113,7 @@ fn create_image_from_video(
 
         // Scale to max size
         let (new_width, new_height) =
-            get_size((buffer.width(), buffer.height()), (max_width, max_height));
+            restrict_size((buffer.width(), buffer.height()), (max_width, max_height));
         if let Ok(buffer) = resize_image(buffer, new_width, new_height) {
             Ok(buffer)
         } else {
